@@ -11,7 +11,7 @@ class Config:
     db_url = os.getenv("DB_URL")
     test_db_url = os.getenv("TEST_DB_URL")
     covalent_key = os.getenv("COVALENT_API_KEY")
-    root_dir = os.path.dirname(os.path.abspath(__file__)).replace("defi_common", "")
+    root_dir = os.path.dirname(os.path.abspath(__file__)).replace("src", "")
     test_data_dir = os.path.join(root_dir, "tests", "test_data")
 
 
